# coding: utf-8

import re
import socket

import pyquery
import click
import requests
from requests.auth import HTTPBasicAuth
from jmb.tools.conf.nginx import parser
from jmb.tools.conf import read

@click.command('enabled')
@click.option('--ssl', is_flag=True, help="Test https even if not present in this nginx conf", default=False)
@click.option('--user', '-u', help="The user for basic authentication")
@click.option('--ip', help="the ip to be used when checking if server_name points correctly")
@click.option('--password', '-p', help="The pass for basic authentication")
@click.option('--ns', help="The nameserver to use", default='8.8.8.8')
@click.option('--response', '-r', is_flag=True, default=False, help="Test the response")
@click.option('--classes', '-c', is_flag=True, default=False,
              help="Test the classes of server_names: ip is 'A', name is 'CNAME'")
@click.option('--verbose', '-v', is_flag=True, help="Be verbose and declare the hostname you're testing")
@click.option('--follow-redirects', '-f', is_flag=True, default=False, help="Follow all redirects to get the real page")
@click.argument('conf', nargs=-1)
def test_resolve(ssl, user, password, verbose, follow_redirects, conf, ip, ns, classes, response):
    "Test conf files: server names correctness"

    if ip and re.search('[a-z]', ip):
        ip = socket.gethostbyname(ip)
    if not ip:
        ip = read.get_ip()

    ctx = click.get_current_context().parent.parent
    for filename in conf:
        try:
            if verbose or ctx.verbose:
                click.secho(filename, fg='magenta')
            pc = parser.ParseConf(filename)
            for srv in pc.servers:
                if classes:
                    srv.test_all_name_classes(ip=ip, nameserver=ns)

                elif response:
                    srv.test_all_name_responses(
                        ip=ip, nameserver=ns, verbose=ctx.verbose, follow_redirects=follow_redirects, ssl=ssl)

                else:
                    srv.test_all_names(ip=ip, nameserver=ns)
        except Exception as e:
            raise

            click.secho("   !!!! Was not able to parse file: {}".format(filename), fg='red')

def test_conf(filename, verbose=False, ip=None, nameserver=None):
    ctx = click.get_current_context().parent.parent
    if ctx.verbose:
        click.secho(filename, fg='magenta')
    pc = parser.ParseConf(filename)
    for srv in pc.servers:
        srv.test_all_names(ip, nameserver=nameserver)

def test_classes(filename, verbose=False, ip=None, nameserver=None):
        srv.test_all_names(ip, nameserver=nameserver)
