# http://www.28lines.com/?p=8
import os
import re
from setuptools import setup, find_packages
from setuptools.command.test import test


class TestRunner(test):

    def run(self, *args, **kwargs):
        if self.distribution.install_requires:
            self.distribution.fetch_build_eggs(
                self.distribution.install_requires)
        if self.distribution.tests_require:
            self.distribution.fetch_build_eggs(
                self.distribution.tests_require)
        from jmb.tools.tests.runtests import runtests
        runtests()


def get_version():
    filename = os.path.join(os.getcwd(), 'jmb', 'tools', '__init__.py')
    with open(filename) as f:
        for line in f.readlines():
            if '__version__' in line:
                m = re.match(r".*__version__ = '(.*?)'", line, flags=re.S)
                return m.group(1)


def get_data_files(*args, **kwargs):

    EXT_PATTERN = kwargs.get('ext') or '\.(html|js|txt|css|po|mo|png|json|xml|yml|conf|cfg)'

    data_dict = {}
    for pkg_name in args:
        data_files = []
        for dirpath, dirnames, filenames in os.walk(pkg_name.replace('.', '/')):
            rel_dirpath = re.sub("^" + pkg_name + '/', '',  dirpath)
            # Ignore dirnames that start with '.'
            for i, dirname in enumerate(dirnames):
                if dirname.startswith('.'):
                    del dirnames[i]
            if filenames:
                data_files += [os.path.join(rel_dirpath, f) for f in filenames
                               if re.search(EXT_PATTERN, f)]
        data_dict[pkg_name] = data_files
    return data_dict

setup(
    name='jmb.tools',
    namespace_packages=['jmb'],
    version=get_version(),
    description='Tools to manage django projects',
    author='ThunderSystems',
    url='http://hg/thundersystems.it/jmb/jmb.tools',
    author_email='dev@thundersystems.it',
    packages=find_packages(exclude=['tests', 'tests.*']),
    platforms='any',
    zip_safe=False,
    classifiers=[
        'Environment :: Jumbo',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Framework :: Django',
        'Framework :: Jumbo',
    ],
    install_requires=[
        'setuptools',
        'Click',
        'dry',
        'requests',
        'pyquery',
        'python-hglib',
        'pydns',      # Non esiste port to Py3
        'pyparsing',
        'pyOpenSSL',
    ],
    entry_points='''
        [console_scripts]
        jmb=jmb.tools.main:cli
    ''',
    package_data=get_data_files('jmb.tools')
    #    test_suite="jmb.tools.tests",
    #    cmdclass={"test": TestRunner},
)
